#!/bin/bash
#----
## @Synopsis	Install script for Centreon Web Front (CentWeb)
## @Copyright	Copyright 2008, Guillaume Watteeux
## @license	GPL : http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
## Install script for Centreon Web Front (CentWeb)
#----
# Install script for Centreon Web Front
#################################
# SVN: $Id: CentWeb.sh 7137 2008-11-24 17:09:55Z jmathis $

# debug ?
#set -x 

echo "$line"
echo -e "\t$(gettext "Start CentWeb Installation")"
echo "$line"

###### check space ton tmp dir
check_tmp_disk_space
[ "$?" -eq 1 ] && purge_centreon_tmp_dir

###### Require
#################################
## Create install_dir_centreon
locate_centreon_installdir
# Create an examples directory to save all important templates and config
[ ! -d $INSTALL_DIR_CENTREON/examples ] && \
	mkdir -p $INSTALL_DIR_CENTREON/examples

## locate or create Centreon log dir
locate_centreon_logdir
locate_centreon_etcdir
locate_centreon_generationdir

## Config pre-require
# define all necessary variables.
locate_rrd_perldir
locate_rrdtool
locate_mail
locate_pear
locate_nagios_installdir
locate_nagios_etcdir
locate_nagios_vardir
locate_nagios_plugindir
locate_nagios_binary
locate_nagios_imgdir
locate_nagiostats_binary
locate_nagios_plugindir
locate_nagios_p1_file $NAGIOS_ETC
locate_cron_d
locate_init_d
locate_php_bin
locate_perl

locate_centpluginstraps_bindir

## Config apache
check_httpd_directory
check_group_apache
check_user_apache
## Check Nagios config
check_user_nagios
check_group_nagios

## NDO binary
## IS NOT POSSIBLE TO USE CENTREON WITHOUT NDO !! CAUTION
if [ "${FORCE_NOT_USE_NDO:-0}" -eq 1 ] ; then 
	NDOMOD_BINARY="CAUTION_NOT_POSSIBLE_TO_USE_CENTREON_WITHOUT_NDO"
else 
	locate_ndomod_binary
fi
## For a moment, Centreon2 does not support when NDO not use.
## by default, I prefert force NDO usage. But you can use 
## FORCE_NOT_USE_NDO
#yes_no_default "$(gettext "Do you want to use NDO ?")" "$no"
#if [ "$?" -eq 0 ] ; then
#	log "INFO" "$(gettext "NDO use...")"
#	locate_ndomod_binary
#fi


## Config Sudo
# I think this process move on CentCore install...
configureSUDO "$INSTALL_DIR_CENTREON/examples"

## Config Apache
configureApache "$INSTALL_DIR_CENTREON/examples"

## Create temps folder and copy all src into
copyInTempFile 2>>$LOG_FILE 

## InstallCentreon

#echo "$line"
#echo -e "\t$(gettext "Start Centreon Web Front Installation")"
#echo -e "$line\n\n"

# change right centreon_log directory
log "INFO" "$(gettext "Change right on") $CENTREON_LOG"
$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -g "$NAGIOS_GROUP" -d 775 \
	"$CENTREON_LOG" >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Change right on") $CENTREON_LOG"

# change right on centreon etc
log "INFO" "$(gettext "Change right on") $CENTREON_ETC"
$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -d 755 \
	"$CENTREON_ETC" >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Change right on") $CENTREON_ETC"

# change right on nagios images/logos
log "INFO" "$(gettext "Change right on") $NAGIOS_IMG"
$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -d 755 \
	"$NAGIOS_IMG" >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Change right on") $NAGIOS_IMG"

## Copy Web Front Source in final
log "INFO" "$(gettext "Copy CentWeb and GPL_LIB in temporary final directory")"
cp -Rf $TMPDIR/src/www $TMPDIR/final
cp -Rf $TMPDIR/src/GPL_LIB $TMPDIR/final

## Create temporary directory
mkdir -p $TMPDIR/work/www/install >> "$LOG_FILE" 2>&1
mkdir -p $TMPDIR/work/cron/reporting >> "$LOG_FILE" 2>&1
mkdir -p $TMPDIR/final/cron/reporting >> "$LOG_FILE" 2>&1

## Install Centreon doc (nagios doc)
$INSTALL_DIR/cinstall $cinstall_opts \
	-g $WEB_GROUP -d 755 -m 644 \
	$TMPDIR/src/doc $INSTALL_DIR_CENTREON/doc >> $LOG_FILE 2>&1
check_result $? "$(gettext "Install nagios documentation")"

## Prepare insertBaseConf.sql
echo -e "$(gettext "In process")"
### Step 1:
## Change Macro on sql file
log "INFO" "$(gettext "Change macros for insertBaseConf.sql")"
${SED} -e 's|/var/log/nagios|'"$NAGIOS_VAR"'|g' \
	-e 's|@NAGIOS_BINARY@|'"$NAGIOS_BINARY"'|g' \
	-e 's|@NAGIOSTATS_BINARY@|'"$NAGIOSTATS_BINARY"'|g' \
	-e 's|@NAGIOS_IMG@|'"$NAGIOS_IMG"'|g' \
	-e 's|/usr/share/nagios|'"$INSTALL_DIR_NAGIOS"'|g' \
	-e 's|nagios|'"$NAGIOS_USER"'|g' \
	-e 's|nagios|'"$NAGIOS_GROUP"'|g' \
	-e 's|/etc/nagios|'"$NAGIOS_ETC"'|g' \
	-e 's|@NAGIOS_PLUGIN@|'"$NAGIOS_PLUGIN"'|g' \
	-e 's|@NAGIOS_BIN@|'"$NAGIOS_BIN"'|g' \
	-e 's|@NAGIOS_INIT_SCRIPT@|'"$NAGIOS_INIT_SCRIPT"'|g' \
	-e 's|/usr/lib/perl5/vendor_perl/5.8.8/i386-linux-thread-multi|'"$RRD_PERL"'|g' \
	-e 's|/usr/share/centreon|'"$INSTALL_DIR_CENTREON"'|g' \
	-e 's|@BIN_RRDTOOL@|'"$BIN_RRDTOOL"'|g' \
	-e 's|@BIN_MAIL@|'"$BIN_MAIL"'|g' \
	-e 's|@INIT_D@|'"$INIT_D"'|g' \
	-e 's|@NDOMOD_BINARY@|'"$NDOMOD_BINARY"'|g' \
	-e 's|@P1_PL@|'"$NAGIOS_P1_FILE"'|g' \
	$TMPDIR/src/www/install/insertBaseConf.sql > \
	$TMPDIR/work/www/install/insertBaseConf.sql
check_result $? "$(gettext "Change macros for insertBaseConf.sql")"

## Copy in final dir
log "INFO" "$( gettext "Copying www/install/insertBaseConf.sql in final directory")"
cp $TMPDIR/work/www/install/insertBaseConf.sql \
	$TMPDIR/final/www/install/insertBaseConf.sql >> "$LOG_FILE" 2>&1

### Step 2: Change right on Centreon WebFront

## use this step to change macros on php file...
echo_info "$(gettext "Change macros for php files")"
macros="/etc/centreon,/usr/share/centreon,@CENTPLUGINSTRAPS_BINDIR@"
find_macros_in_dir "$macros" "$TMPDIR/src/" "www" "*.php" "file_php_temp"

log "INFO" "$(gettext "Apply macros")"

flg_error=0
${CAT} "$file_php_temp" | while read file ; do
	log "MACRO" "$(gettext "Change macro for") : $file"
	[ ! -d $(dirname $TMPDIR/work/$file) ] && \
		mkdir -p  $(dirname $TMPDIR/work/$file) >> $LOG_FILE 2>&1
	${SED} -e 's|/etc/centreon|'"$CENTREON_ETC"'|g' \
		-e 's|/usr/share/centreon|'"$CENTREON_GENDIR"'|g' \
		-e 's|@CENTPLUGINSTRAPS_BINDIR@|'"$CENTPLUGINSTRAPS_BINDIR"'|g' \
		-e 's|/var/lib/centreon|'"$CENTREON_VARLIB"'|g' \
		$TMPDIR/src/$file > $TMPDIR/work/$file
		[ $? -ne 0 ] && flg_error=1
	log "MACRO" "$(gettext "Copy in final dir") : $file"
	cp -f $TMPDIR/work/$file $TMPDIR/final/$file >> $LOG_FILE 2>&1 
done
check_result $flg_error "$(gettext "Change macros for php files")"

### Step 3: Change right on nagios_etcdir
log "INFO" "$(gettext "Change right on") $NAGIOS_ETC" 
flg_error=0
$INSTALL_DIR/cinstall $cinstall_opts \
	-g "$WEB_GROUP" -d 775 \
	"$NAGIOS_ETC" >> "$LOG_FILE" 2>&1
[ $? -ne 0 ] && flg_error=1

find "$NAGIOS_ETC" -type f -print | \
	xargs -I '{}' ${CHMOD}  775 '{}' >> "$LOG_FILE" 2>&1
[ $? -ne 0 ] && flg_error=1
find "$NAGIOS_ETC" -type f -print | \
	xargs -I '{}' ${CHOWN} "$WEB_USER":"$WEB_GROUP" '{}' >> "$LOG_FILE" 2>&1
[ $? -ne 0 ] && flg_error=1
check_result $flg_error "$(gettext "Change right on") $NAGIOS_ETC" 

### Step 4: Copy final stuff in system directoy
echo_info "$(gettext "Copy CentWeb in system directory")"
$INSTALL_DIR/cinstall $cinstall \
	-u "$WEB_USER" -g "$WEB_GROUP" -d 755 \
	$INSTALL_DIR_CENTREON/www >> "$LOG_FILE" 2>&1

$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -g "$WEB_GROUP" -d 755 -m 644 \
	-p $TMPDIR/final/www \
	$TMPDIR/final/www/* $INSTALL_DIR_CENTREON/www/ >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Install CentWeb (web front of centreon)")"

[ ! -d "$INSTALL_DIR_CENTREON/www/modules" ] && \
	$INSTALL_DIR/cinstall $cinstall_opts \
		-u "$WEB_USER" -g "$WEB_GROUP" -d 755 \
		$INSTALL_DIR_CENTREON/www/modules >> "$LOG_FILE" 2>&1

[ ! -d "$INSTALL_DIR_CENTREON/www/img/media" ] && \
	$INSTALL_DIR/cinstall $cinstall_opts \
		-u "$WEB_USER" -d 755 \
		$INSTALL_DIR_CENTREON/www/img/media >> "$LOG_FILE" 2>&1

$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -g "$WEB_GROUP" -d 775 \
	$CENTREON_GENDIR/filesGeneration/nagiosCFG >> "$LOG_FILE" 2>&1
# By default, CentWeb use a filesGeneration directory in install dir.
# I create a symlink to continue in a same process
[ ! -h $INSTALL_DIR_CENTREON/filesGeneration -a ! -d $INSTALL_DIR_CENTREON/filesGeneration ] && \
	ln -s $CENTREON_GENDIR/filesGeneration $INSTALL_DIR_CENTREON >> $LOG_FILE 2>&1

$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -g "$WEB_GROUP" -d 775 -v \
	$CENTREON_GENDIR/filesUpload/nagiosCFG >> "$LOG_FILE" 2>&1
# By default, CentWeb use a filesGeneration directory in install dir.
# I create a symlink to continue in a same process
[ ! -h $INSTALL_DIR_CENTREON/filesUpload -a ! -d $INSTALL_DIR_CENTREON/filesUpload ] && \
	ln -s $CENTREON_GENDIR/filesUpload $INSTALL_DIR_CENTREON >> $LOG_FILE 2>&1

log "INFO" "$(gettext "Copying GPL_LIB")"
$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$WEB_USER" -g "$WEB_GROUP" -d 755 -m 644 \
	$TMPDIR/final/GPL_LIB $INSTALL_DIR_CENTREON/GPL_LIB >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Install libraries")"

## Cron stuff
## need to add stuff for Unix system... (freeBSD...)
log "INFO" "$(gettext "Change macros for centreon.cron")"
${SED} -e 's|/usr/bin/php|'"$PHP_BIN"'|g' \
	-e 's|/usr/bin/perl|'"$BIN_PERL"'|g' \
	-e 's|/usr/share/centreon|'"$INSTALL_DIR_CENTREON"'|g' \
	-e 's|/var/log/centreon|'"$CENTREON_LOG"'|g' \
	-e 's|nagios|'"$NAGIOS_USER"'|g' \
	$BASE_DIR/tmpl/install/centreon.cron > $TMPDIR/work/centreon.cron
check_result $? "$(gettext "Change macros for centreon.cron")"
cp $TMPDIR/work/centreon.cron $TMPDIR/final/centreon.cron >> "$LOG_FILE" 2>&1

log "INFO" "$(gettext "Install centreon.cron")"
$INSTALL_DIR/cinstall $cinstall_opts \
	-m 644 \
	$TMPDIR/final/centreon.cron $CRON_D/centreon >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Install Centreon cron.d file")"

## cron binary
cp -R $TMPDIR/src/cron/ $TMPDIR/final/
log "INFO" "$(gettext "Change macros for archiveDayLog")"
${SED} -e 's|/etc/centreon|'"$CENTREON_ETC"'|g' \
	$TMPDIR/src/cron/archiveDayLog > \
	$TMPDIR/work/cron/archiveDayLog
check_result $? "$(gettext "Change macros for archiveDayLog")"

cp -f $TMPDIR/work/cron/archiveDayLog \
	$TMPDIR/final/cron/archiveDayLog

log "INFO" "$(gettext "Change macros for centAcl.php")"
${SED} -e 's|/etc/centreon|'"$CENTREON_ETC"'|g' \
	$TMPDIR/src/cron/centAcl.php > $TMPDIR/work/cron/centAcl.php
check_result $? "$(gettext "Change macros for centAcl.php")"

cp -f $TMPDIR/work/cron/centAcl.php \
	$TMPDIR/final/cron/centAcl.php >> "$LOG_FILE" 2>&1

log "INFO" "$(gettext "Install cron directory")"
$INSTALL_DIR/cinstall $cinstall_opts \
	-u "$NAGIOS_USER" -g "$WEB_GROUP" -d 755 -m 755 \
	$TMPDIR/final/cron $INSTALL_DIR_CENTREON/cron >> "$LOG_FILE" 2>&1
check_result $? "$(gettext "Install cron directory")"

## Prepare to install all pear modules needed.
# use check_pear.php script
echo -e "$(gettext "Pear Modules")"
pear_module="0"
while [ "$pear_module" -eq 0 ] ; do 
	check_pear_module "$INSTALL_VARS_DIR/$PEAR_MODULES_LIST"
	if [ "$?" -ne 0 ] ; then
		yes_no_default "$(gettext "Do you want me to install/upgrade your PEAR modules")" "$yes"
		if [ "$?" -eq 0 ] ; then
			upgrade_pear_module "$INSTALL_VARS_DIR/$PEAR_MODULES_LIST"
			install_pear_module "$INSTALL_VARS_DIR/$PEAR_MODULES_LIST"
		else
			pear_module="1"
		fi
	else 
		echo_success "$(gettext "All PEAR modules")" "$ok"
		pear_module="1"
	fi
done

## Create configfile for web install
createConfFile

## Write install config file
createCentreonInstallConf

## wait sql inject script....

