#!/usr/bin/perl

#==========================================================================
# Summary
#==========================================================================
# ! Short description !
# 
# ! Long Description !
# 
#
# Copyright (C) 2008 Olivier LI-KIANG-CHEONG <olikiangcheong@linagora.com>
# Copyright (C) 2008 LINAGORA <http://www.linagora.com>
# 
#==========================================================================
# License: GPLv2
#==========================================================================
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# GPL License: http://www.gnu.org/licenses/gpl.txt
#
#==========================================================================
# Please visit http://www.linagora.org for other contributions
#==========================================================================

#==========================================================================
# Changelog
#==========================================================================
# Version 0.1 (2008/11/17):
# - First version
# Author: Olivier LI-KIANG-CHEONG
#==========================================================================

#==========================================================================
# Version
#==========================================================================
my $VERSION = '0.1';
my $TEMPLATE_VERSION = '1.0.0';

#==========================================================================
# OID
#==========================================================================
my $cpu_base = "1.3.6.1.4.1.43.45.1.6.1.1.1"; 
my $cpu_5sec = "1.3.6.1.4.1.43.45.1.6.1.1.1.2"; # cpu last 5 sec
my $cpu_1min = "1.3.6.1.4.1.43.45.1.6.1.1.1.3"; # cpu last 1 min
my $cpu_5min = "1.3.6.1.4.1.43.45.1.6.1.1.1.4"; # cpu last 5 min

my $mem_base = "1.3.6.1.4.1.43.45.1.6.1.2.1.1";
my $mem_total = "1.3.6.1.4.1.43.45.1.6.1.2.1.1.2";   # memory totale
my $mem_free =  "1.3.6.1.4.1.43.45.1.6.1.2.1.1.3";   # memory free

# For test net-snmpt
#my $mem_free = "1.3.6.1.4.1.2021.4.6.0";  # Real memory free
#my $mem_total = "1.3.6.1.4.1.2021.4.5.0";  # Real memory total

#==========================================================================
# Modules
#==========================================================================
use strict;
use lib '/var/lib/nagios/plugins';
use utils qw /$TIMEOUT %ERRORS &print_revision &support/;
use Getopt::Long;
&Getopt::Long::config('bundling');
use File::Basename;
use POSIX;
use Net::SNMP;

#==========================================================================
# Options
#==========================================================================
my $progname = basename($0);
my $help;
my $version;
my $verbose = 0;
my $host;
my $warning;
my $critical;
my $port = 161;
my $timeout = $TIMEOUT;
# For SNMP plugins
my $snmp_version;
my $community;
my $logname;
my $privpasswd;
my $cpu;
my $mem;

GetOptions(
        'h'=> \$help,                       'help'=> \$help,
        'V'=> \$version,                    'version'=> \$version,
        'v+'=> \$verbose,			        'verbose+'=> \$verbose,
        'H:s'=> \$host,                     'host:s'=> \$host,
        'w:s'=> \$warning,                  'warning:s'=> \$warning,
        'c:s'=> \$critical,			        'critical:s'    => \$critical,
        'p:i'=> \$port,                     'port:i'=> \$port,
        't:i'=> \$timeout,                  'timeout:i'=> \$timeout,
        # For SNMP plugins
        's:s'=> \$snmp_version,             'snmp_version:s'=> \$snmp_version,
        'C:s'=> \$community,                'community:s'=> \$community,
        'l:s'=> \$logname,                  'logname:s'=> \$logname,
        'X:s'=> \$privpasswd,               'privpasswd:s'=> \$privpasswd,
                                            'cpu'=> \$cpu,
                                            'mem'=> \$mem
        );

#==========================================================================
# Usage
#==========================================================================
sub print_usage {
    print "Usage: \n";
    print "$progname [--cpu|--mem] -H <hostname> [-p <port>] -w <warning> -c <critical> --snmp_version=<version> -C <community> [-l <login>] [-X password]\n\n";
    print "Examples : \n";
    print "Check % Memory used : $progname -H localhost -w 90 -c 95 --mem --snmp_version=2 -C public\n";
    print "Check % CPU average (last 5 sec, 1 min, 5 min) : $progname -H localhost -w 90,90,90 -c 95,95,95 --cpu --snmp_version=2 -C public\n\n";
    print "Use option --help for more information\n\n";
    print "$progname comes with ABSOLUTELY NO WARRANTY\n\n";
}

#=========================================================================
# Version
#=========================================================================
if ($version) {
    &print_revision($progname, "\$Revision: $VERSION (TPL: $TEMPLATE_VERSION)\$");
    exit $ERRORS{'UNKNOWN'};
}

#=========================================================================
# Help
#=========================================================================
if ($help) {
    &print_revision($progname, "\$Revision: $VERSION\$");
    
    print "\n\nCheck 3com cpu and memory usage. Models 8807 and 5500\n\n";

    &print_usage;

    print "-v, --verbose\n";
    print "\tPrint extra debugging information.\n";
    print "-V, --version\n";
    print "\tPrint version and exit.\n";
    print "-h, --help\n";
    print "\tPrint this help message and exit.\n";
    print "-H, --host=STRING\n";
    print "\tIP or name (FQDN).\n";
    print "-p, --port=INTEGER\n";
    print "\tPort to connect to. Default is 161\n";
    print "-w, --warning=DOUBLE\n";
    print "\t Level to return a warning status.\n";
    print "-c, --critical=DOUBLE\n";
    print "\tLevel to return a critical status.\n";
    print "-t, --timeout=INTEGER\n";
    print "\tSeconds before connection times out (Default: $TIMEOUT).\n";
    print "--snmp_version=(1|2c|3)\n";
    print "\tSNMP protocol version.\n";
    print "-C, --community=STRING\n";
    print "\tSNMP community (v1 and v2c).\n";
    print "-l, --logname=STRING\n";
    print "\tUser id for login.\n";
    print "-X, --privpasswd=STRING\n";
    print "\tSNMP cipher password (v3).\n";
    print "--cpu\n";
    print "\tCPU usage.\n";
    print "--mem\n";
    print "\tMemmory usage.\n";
    print "\n";

    #&support;

    exit $ERRORS{'UNKNOWN'};
}


#=========================================================================
# Functions
#=========================================================================

# DEBUG function
sub verbose {
    my $output_code = shift ;
    my $text = shift ;
    if ( $verbose >= $output_code ) {
        printf "VERBOSE $output_code ===> %s\n", $text;
    }
} 

# Arrondi
sub round ($$) {
    sprintf "%.$_[1]f", $_[0];
}


# check if -H is used 
sub check_host_param{
    if ( !defined( $host) ) {
        printf "UNKNOWN: you have to define a hostname.\n";
        exit $ERRORS{UNKNOWN};
    }
}


# check if -w is used 
sub check_warning_param{
    if ( !defined( $warning) ) {
        printf "UNKNOWN: you have to define a warning thresold.\n";
        exit $ERRORS{UNKNOWN};
    }
}


# check if -c is used 
sub check_critical_param{
    if ( !defined( $critical) ) {
        printf "UNKNOWN: you have to define a critical thresold.\n";
        exit $ERRORS{UNKNOWN};
    }
}

# check if --cpu or --mem is used 
sub check_indicateur{
    if ( !defined( $cpu) && !defined( $mem) ) {
            printf "UNKNOWN: you have to define a indicateur. Use --cpu or --mem\n";
            exit $ERRORS{UNKNOWN};
    }
}

# check if --snmp_version is used 
sub check_snmp_version{
    if ( !defined($snmp_version) ) {
            printf "UNKNOWN: you have to define snmp version\n";
            exit $ERRORS{UNKNOWN};
    } elsif (($snmp_version ne "1") && ($snmp_version ne "2c") && ($snmp_version ne "3")) {
        printf "UNKNOWN: you have to define snmp version in 1, 2c or 3\n";
        exit $ERRORS{UNKNOWN};
    } elsif ($snmp_version eq "3") {
        # check if -l and -X
        if ( !defined($logname) || !defined($privpasswd)) {
             printf "UNKNOWN: you have to use authentication. Use -l and -X\n";
        }
    }
}

# check if --C is used 
sub check_community{
    if ( !defined( $community) ) {
            printf "UNKNOWN: you have to define a community\n";
            exit $ERRORS{UNKNOWN};
    }
}

#=========================================================================
# Main
#=========================================================================


check_host_param();
check_warning_param();
check_critical_param();
check_indicateur();
check_snmp_version();
check_community();

my $session;
my $error;
if ( defined($privpasswd) && defined($logname) && ($snmp_version == 3)) {
    # SNMPv3 login
    verbose(1,"SNMPv3 login");
    ($session, $error) = Net::SNMP->session(
      -hostname         => $host,
      -version          => $snmp_version,
      -username         => $logname,
      -authpassword     => $privpasswd,
      -authprotocol     => 'md5',
      -privpassword     => $privpasswd,
      -timeout          => $timeout
   );
} else {
    # SNMPV1 login
    ($session, $error) = Net::SNMP->session(
        -hostname  => $host,
        -community => $community,
        -port      => $port,
        -timeout   => $timeout
    );
}

if (!defined($session)) {
    printf("ERROR opening session: %s.\n", $error);
    exit $ERRORS{"UNKNOWN"};
}

# Global variable
my $resultat=undef;

if (defined($cpu)) {
    # Check CPU
    my $resultat = $session->get_table(
        -baseoid => $cpu_base
    );

    if (!defined($resultat)) {
       printf("ERROR: Description table : %s.\n", $session->error);
       $session->close;
       exit $ERRORS{"UNKNOWN"};
    }

    $session->close;
    
    my $cpu_info = 0;
    my @res_cpu = undef;
    foreach my $key (keys %$resultat) {
        if ($key =~ /$cpu_5sec/) {
            $cpu_info++;
            $res_cpu[0] = $$resultat{$key}; 
        } elsif ($key =~ /$cpu_1min/) {
            $res_cpu[1] = $$resultat{$key}; 
            $cpu_info++;
        } elsif ($key =~ /$cpu_5min/) {
            $res_cpu[2] = $$resultat{$key}; 
            $cpu_info++;
        }
    }

    if (($cpu_info == 0) || ($cpu_info =! 3)) {
        print "No CPU information : UNKNOWN\n";
        exit $ERRORS{"UNKNOWN"};
    }

    my $exit_val = $ERRORS{"OK"};

    my @critical_L = split(/,/, $critical); # critical level
    my @warning_L = split(/,/, $warning);  # warning level

    print "CPU : 5 sec=$res_cpu[0], 1 min=$res_cpu[1], 5 min=$res_cpu[2] :";

    for (my $i = 0; $i < 3; $i++) {
        if ( $res_cpu[$i] > $critical_L[$i] ) {
            print " $res_cpu[$i] > $critical_L[$i] : CRITICAL";
            $exit_val = $ERRORS{"CRITICAL"};
        }
        if ( $res_cpu[$i] > $warning_L[$i] ) {
            # output warn error only if no critical was found
            if ($exit_val eq $ERRORS{"OK"}) {
                print " $res_cpu[$i] > $warning_L[$i] : WARNING";
                $exit_val = $ERRORS{"WARNING"};
            }
        }
    }
    print " OK" if ($exit_val eq $ERRORS{"OK"});
    # Print perfdata
    print " | cpu_5_sec=$res_cpu[0]%;$warning_L[0];$critical_L[0];0;100 ";
    print "cpu_1_min=$res_cpu[1]%;$warning_L[1];$critical_L[1];0;100 ";
    print "cpu_5_min=$res_cpu[2]%;$warning_L[2];$critical_L[2];0;100\n";
    exit $exit_val;

} elsif (defined($mem)) { 
    # Check MEM
    my @oidlists = ($mem_total,$mem_free );
    my $resultat = $session->get_table(
        -baseoid => $mem_base
    );

    if (!defined($resultat)) {
       printf("ERROR: Description table : %s.\n", $session->error);
       $session->close;
       exit $ERRORS{"UNKNOWN"};
    }

    $session->close;
    
    my $mem_info = 0;
    my $res_mem_total;
    my $res_mem_free;
    foreach my $key (keys %$resultat) {
        if ($key =~ /$mem_total/) {
            $mem_info++;
            $res_mem_total = $$resultat{$key}; 
        } elsif ($key =~ /$mem_free/) {
            $res_mem_free = $$resultat{$key}; 
            $mem_info++;
        }
    }

    if (($mem_info == 0) || ($mem_info =! 2)) {
        print "No Memory information : UNKNOWN\n";
        exit $ERRORS{"UNKNOWN"};
    }

    print "Memory total=$res_mem_total free=$res_mem_free :";

    # Consolidate datas
    my $used = $res_mem_total-$res_mem_free;
    my $percent_used = round($used*100/($res_mem_total),0);
    my $exit_val = $ERRORS{"OK"};
   
    if ( $percent_used > $critical) {
            print " Memory Used $percent_used% > $critical% : CRITICAL";
            $exit_val = $ERRORS{"CRITICAL"};
    } elsif ($percent_used > $warning) {
        print " Memory Used $percent_used% > $warning% : WARNING";
        $exit_val = $ERRORS{"WARNING"};
    }

    print " OK" if ($exit_val eq $ERRORS{"OK"});

    # Print perfdata
    print " | memory_used=$percent_used%;$warning;$critical;0;100\n";
    exit $exit_val;

}
