#! /usr/bin/perl

#==========================================================================
# Summary
#==========================================================================
# ! Short description !
# 
# ! Long Description !
# 
#
# Copyright (C) 2008 Olivier LI-KIANG-CHEONG <olikiangcheong@linagora.com>
# Copyright (C) 2008 LINAGORA <http://www.linagora.com>
# 
#==========================================================================
# License: GPLv2
#==========================================================================
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# GPL License: http://www.gnu.org/licenses/gpl.txt
#
#==========================================================================
# Please visit http://www.linagora.org for other contributions
#==========================================================================

#==========================================================================
# Changelog
#==========================================================================
# Version 0.1 (2008/11/17):
# - First version
# Author: Olivier LI-KIANG-CHEONG
#==========================================================================

#==========================================================================
# Version
#==========================================================================
my $VERSION = '0.1';
my $TEMPLATE_VERSION = '1.0.0';

#==========================================================================
# OID
#==========================================================================
my $master_processor_1sec =  "1.3.6.1.4.1.1872.2.5.1.2.2.1.0"; 
my $master_processor_4sec =  "1.3.6.1.4.1.1872.2.5.1.2.2.2.0";
my $master_processor_64sec = "1.3.6.1.4.1.1872.2.5.1.2.2.3.0";

my $switch_processor_1sec =  "1.3.6.1.4.1.1872.2.5.1.2.4.1.1.2";
my $switch_processor_4sec =  "1.3.6.1.4.1.1872.2.5.1.2.4.1.1.3";
my $switch_processor_64sec = "1.3.6.1.4.1.1872.2.5.1.2.4.1.1.4";

my $sp_current_number_of_sessions = "1.3.6.1.4.1.1872.2.5.4.2.1.5.1.3";

# NOT USED
my $number_connections_auxiliary_sessions_table = "1.3.6.1.4.1.1872.2.5.4.2.1.6.1.3";
my $current_number_bindings = "1.3.6.1.4.1.1872.2.5.4.2.5.2";
my $current_number_of_different_TCP_sessions_using_SSL_service = "1.3.6.1.4.1.1872.2.5.4.2.16.2";

#==========================================================================
# Modules
#==========================================================================
use strict;
use lib '/var/lib/nagios/plugins';
use utils qw /$TIMEOUT %ERRORS &print_revision &support/;
use Getopt::Long;
&Getopt::Long::config('bundling');
use File::Basename;
use POSIX;
use Net::SNMP;

#==========================================================================
# Options
#==========================================================================
my $progname = basename($0);
my $help;
my $version;
my $verbose = 0;
my $host;
my $warning;
my $critical;
my $port = 161;
my $timeout = $TIMEOUT;
# For SNMP plugins
my $snmp_version;
my $community;
my $logname;
my $privpasswd;

my $masterprocessor;
my $switchprocessor;
my $sessions;

GetOptions(
        'h'=> \$help,                       'help'=> \$help,
        'V'=> \$version,                    'version'=> \$version,
        'v+'=> \$verbose,			        'verbose+'=> \$verbose,
        'H:s'=> \$host,                     'host:s'=> \$host,
        'w:s'=> \$warning,                  'warning:s'=> \$warning,
        'c:s'=> \$critical,			        'critical:s'    => \$critical,
        'p:i'=> \$port,                     'port:i'=> \$port,
        't:i'=> \$timeout,                  'timeout:i'=> \$timeout,
        # For SNMP plugins
        's:s'=> \$snmp_version,             'snmp_version:s'=> \$snmp_version,
        'C:s'=> \$community,                'community:s'=> \$community,
        'l:s'=> \$logname,                  'logname:s'=> \$logname,
        'X:s'=> \$privpasswd,               'privpasswd:s'=> \$privpasswd,
                                            'masterprocessor'=> \$masterprocessor,
                                            'switchprocessor:i'=> \$switchprocessor,
                                            'sessions:i'=> \$sessions,
        );

#==========================================================================
# Usage
#==========================================================================
sub print_usage {
    print "Usage: \n";
    print "$progname [--masterprocessor|--switchprocessor=ID|--sessions=NB] -H <hostname> [-p <port>] -w <warning> -c <critical> --snmp_version=<version> -C <community> [-l <login>] [-X password]\n\n";
    print "Examples : \n";
    print "Check % Master Processor : $progname --masterprocessor -H localhost -w 90,90,90 -c 95,95,95 --snmp_version=2c -C public\n";
    print "Check % Switch Processor (last 5 sec, 1 min, 5 min) : $progname --switchprocessor -H localhost -w 90,90,90 -c 95,95,95 --snmp_version=2c -C public\n\n";
    print "Check % Session Number : $progname --sessions -H localhost -w 100  -c 150 --snmp_version=2c -C public\n\n";
    print "Use option --help for more information\n\n";
    print "$progname comes with ABSOLUTELY NO WARRANTY\n\n";
}

#=========================================================================
# Version
#=========================================================================
if ($version) {
    &print_revision($progname, "\$Revision: $VERSION (TPL: $TEMPLATE_VERSION)\$");
    exit $ERRORS{'UNKNOWN'};
}

#=========================================================================
# Help
#=========================================================================
if ($help) {
    &print_revision($progname, "\$Revision: $VERSION\$");
    
    print "\n\nCheck Nortel-Alteon master processor, switch processor and number sessions.\n\n";

    &print_usage;

    print "-v, --verbose\n";
    print "\tPrint extra debugging information.\n";
    print "-V, --version\n";
    print "\tPrint version and exit.\n";
    print "-h, --help\n";
    print "\tPrint this help message and exit.\n";
    print "-H, --host=STRING\n";
    print "\tIP or name (FQDN).\n";
    print "-p, --port=INTEGER\n";
    print "\tPort to connect to. Default is 161\n";
    print "-w, --warning=DOUBLE\n";
    print "\t Level to return a warning status.\n";
    print "-c, --critical=DOUBLE\n";
    print "\tLevel to return a critical status.\n";
    print "-t, --timeout=INTEGER\n";
    print "\tSeconds before connection times out (Default: $TIMEOUT).\n";
    print "--snmp_version=(1|2c|3)\n";
    print "\tSNMP protocol version.\n";
    print "-C, --community=STRING\n";
    print "\tSNMP community (v1 and v2c).\n";
    print "-l, --logname=STRING\n";
    print "\tUser id for login.\n";
    print "-X, --privpasswd=STRING\n";
    print "\tSNMP cipher password (v3).\n";
    print "--masterprocessor\n";
    print "\tCheck Master Processor average on 1s,4s,64s\n";
    print "--switchprocessor=INTEGER\n";
    print "\tCheck Switch Processor on 1s,4s,64s for the processor ID (1-4).\n";
    print "--sessions=INTEGER\n";
    print "\tCheck the number of sessions.\n";
    print "\n";
    #&support;

    exit $ERRORS{'UNKNOWN'};
}


#=========================================================================
# Functions
#=========================================================================

# DEBUG function
sub verbose {
    my $output_code = shift ;
    my $text = shift ;
    if ( $verbose >= $output_code ) {
        printf "VERBOSE $output_code ===> %s\n", $text;
    }
} 

# Arrondi
sub round ($$) {
    sprintf "%.$_[1]f", $_[0];
}


# check if -H is used 
sub check_host_param{
    if ( !defined( $host) ) {
        printf "UNKNOWN: you have to define a hostname.\n";
        exit $ERRORS{UNKNOWN};
    }
}


# check if -w is used 
sub check_warning_param{
    if ( !defined( $warning) ) {
        printf "UNKNOWN: you have to define a warning thresold.\n";
        exit $ERRORS{UNKNOWN};
    }
}


# check if -c is used 
sub check_critical_param{
    if ( !defined( $critical) ) {
        printf "UNKNOWN: you have to define a critical thresold.\n";
        exit $ERRORS{UNKNOWN};
    }
}

# check if --masterprocessor --switchprocessor --sessions used 
sub check_indicateur{
    if ( !defined($masterprocessor) && 
         !defined($switchprocessor) && 
         !defined($sessions)) {
            printf "UNKNOWN: you have to define a indicateur. Use --cpu or --mem\n";
            exit $ERRORS{UNKNOWN};
    }
}

# check if --snmp_version is used 
sub check_snmp_version{
    if ( !defined($snmp_version) ) {
            printf "UNKNOWN: you have to define snmp version\n";
            exit $ERRORS{UNKNOWN};
    } elsif (($snmp_version ne "1") && ($snmp_version ne "2c") && ($snmp_version ne "3")) {
        printf "UNKNOWN: you have to define snmp version in 1, 2c or 3\n";
        exit $ERRORS{UNKNOWN};
    } elsif ($snmp_version eq "3") {
        # check if -l and -X
        if ( !defined($logname) || !defined($privpasswd)) {
             printf "UNKNOWN: you have to use authentication. Use -l and -X\n";
        }
    }
}

# check if --C is used 
sub check_community{
    if ( !defined( $community) ) {
            printf "UNKNOWN: you have to define a community\n";
            exit $ERRORS{UNKNOWN};
    }
}

#=========================================================================
# Main
#=========================================================================


check_host_param();
check_warning_param();
check_critical_param();
check_indicateur();
check_snmp_version();
check_community();

my $session;
my $error;
if ( defined($privpasswd) && defined($logname) && ($snmp_version == 3)) {
    # SNMPv3 login
    verbose(1,"SNMPv3 login");
    ($session, $error) = Net::SNMP->session(
      -hostname         => $host,
      -version          => $snmp_version,
      -username         => $logname,
      -authpassword     => $privpasswd,
      -authprotocol     => 'md5',
      -privpassword     => $privpasswd,
      -timeout          => $timeout
   );
} else {
    # SNMPV1 login
    ($session, $error) = Net::SNMP->session(
        -hostname  => $host,
        -community => $community,
        -port      => $port,
        -timeout   => $timeout
    );
}

if (!defined($session)) {
    printf("ERROR opening session: %s.\n", $error);
    exit $ERRORS{"UNKNOWN"};
}

# Global variable
my $resultat=undef;

if (defined($masterprocessor)) {
    # Check master processor
    my @oidlists = ($master_processor_1sec,$master_processor_4sec,$master_processor_64sec);
    my $resultat = $session->get_request(
        -varbindlist => \@oidlists
    );

    if (!defined($resultat)) {
       printf("ERROR: Description table : %s.\n", $session->error);
       $session->close;
       exit $ERRORS{"UNKNOWN"};
    }

    $session->close;

    if (!defined ($$resultat{$master_processor_64sec})) {
        print "No Master processor information : UNKNOWN\n";
        exit $ERRORS{"UNKNOWN"};
    }

    my @res_master_processor = undef;

    $res_master_processor[0] = $$resultat{$master_processor_1sec};
    $res_master_processor[1] = $$resultat{$master_processor_4sec};
    $res_master_processor[2] = $$resultat{$master_processor_64sec};

    my $exit_val = $ERRORS{"OK"};

    my @critical_L = split(/,/, $critical); # critical level
    my @warning_L = split(/,/, $warning);  # warning level

    print "Master processor : 1 sec=$res_master_processor[0], 4 sec=$res_master_processor[1], 64 sec=$res_master_processor[2] :";

    for (my $i = 0; $i < 3; $i++) {
        if ( $res_master_processor[$i] > $critical_L[$i] ) {
            print " $res_master_processor[$i] > $critical_L[$i] : CRITICAL";
            $exit_val = $ERRORS{"CRITICAL"};
        }
        if ( $res_master_processor[$i] > $warning_L[$i] ) {
            # output warn error only if no critical was found
            if ($exit_val eq $ERRORS{"OK"}) {
                print " $res_master_processor[$i] > $warning_L[$i] : WARNING";
                $exit_val = $ERRORS{"WARNING"};
            }
        }
    }
    print " OK" if ($exit_val eq $ERRORS{"OK"});
    # Print perfdata
    print " | master_processor_1sec=$res_master_processor[0]%;$warning_L[0];$critical_L[0];0;100 ";
    print "master_processor_4sec=$res_master_processor[1]%;$warning_L[1];$critical_L[1];0;100 ";
    print "master_processor_64sec=$res_master_processor[2]%;$warning_L[2];$critical_L[2];0;100\n";
    exit $exit_val;

} elsif (defined($switchprocessor)) {
    # Check switch processor
    $switch_processor_1sec = $switch_processor_1sec.".$switchprocessor";
    $switch_processor_4sec = $switch_processor_4sec.".$switchprocessor";
    $switch_processor_64sec = $switch_processor_64sec.".$switchprocessor";
    my @oidlists = ($switch_processor_1sec,$switch_processor_4sec,$switch_processor_64sec);
    my $resultat = $session->get_request(
        -varbindlist => \@oidlists
    );

    if (!defined($resultat)) {
       printf("ERROR: Description table : %s.\n", $session->error);
       $session->close;
       exit $ERRORS{"UNKNOWN"};
    }

    $session->close;

    if (!defined ($$resultat{$switch_processor_64sec})) {
        print "No Switch processor : UNKNOWN\n";
        exit $ERRORS{"UNKNOWN"};
    }

    my @res_switch_processor = undef;

    $res_switch_processor[0] = $$resultat{$switch_processor_1sec};
    $res_switch_processor[1] = $$resultat{$switch_processor_4sec};
    $res_switch_processor[2] = $$resultat{$switch_processor_64sec};

    my $exit_val = $ERRORS{"OK"};

    my @critical_L = split(/,/, $critical); # critical level
    my @warning_L = split(/,/, $warning);  # warning level

    print "Switch processor : 1 sec=$res_switch_processor[0], 4 sec=$res_switch_processor[1], 64 sec=$res_switch_processor[2] :";

    for (my $i = 0; $i < 3; $i++) {
        if ( $res_switch_processor[$i] > $critical_L[$i] ) {
            print " $res_switch_processor[$i] > $critical_L[$i] : CRITICAL";
            $exit_val = $ERRORS{"CRITICAL"};
        }
        if ( $res_switch_processor[$i] > $warning_L[$i] ) {
            # output warn error only if no critical was found
            if ($exit_val eq $ERRORS{"OK"}) {
                print " $res_switch_processor[$i] > $warning_L[$i] : WARNING";
                $exit_val = $ERRORS{"WARNING"};
            }
        }
    }
    print " OK" if ($exit_val eq $ERRORS{"OK"});
    # Print perfdata
    print " | switch_processor_1sec=$res_switch_processor[0]%;$warning_L[0];$critical_L[0];0;100 ";
    print "switch_processor_4sec=$res_switch_processor[1]%;$warning_L[1];$critical_L[1];0;100 ";
    print "switch_processor_64sec=$res_switch_processor[2]%;$warning_L[2];$critical_L[2];0;100\n";
    exit $exit_val;

} 
elsif (defined($sessions)) { 
    # Check sessions
    my $resultat = $session->get_table(
        -baseoid => $sp_current_number_of_sessions
    );

    if (!defined($resultat)) {
       printf("ERROR: Description table : %s.\n", $session->error);
       $session->close;
       exit $ERRORS{"UNKNOWN"};
    }

    $session->close;

    if (scalar(keys %$resultat) == 0) {
        print "No number sessions information : UNKNOWN\n";
        exit $ERRORS{"UNKNOWN"};
    }

    my $res_sp_current_number_of_sessions = 0;
    foreach my $key (keys %$resultat) {
        $res_sp_current_number_of_sessions = $res_sp_current_number_of_sessions+$$resultat{$key};
    }

    my $exit_val = $ERRORS{"OK"};
    print "SP current number sessions=$res_sp_current_number_of_sessions ";

    if ( $res_sp_current_number_of_sessions > $critical) {
            print "> $critical : CRITICAL";
            $exit_val = $ERRORS{"CRITICAL"};
    } elsif ( $res_sp_current_number_of_sessions > $warning) {
        print "> $warning : WARNING";
        $exit_val = $ERRORS{"WARNING"};
    }

    print " OK" if ($exit_val eq $ERRORS{"OK"});

    # Print perfdata
    print " | current_number_of_sessions=$res_sp_current_number_of_sessions;$warning;$critical;0;200\n";
    exit $exit_val;

}

